==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextSupport__24BCSIterator.h <==
// public final class java.beans.beancontext.BeanContextSupport$BCSIterator

// class file dependencies
// @dep_class ade893ef1e681103 java_beans_beancontext_BeanContextSupport__24BCSIterator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextSupport__24BCSIterator_H_
#define _JC_java_beans_beancontext_BeanContextSupport__24BCSIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object;

typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *);

// Virtual methods
extern jboolean _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *);
extern void _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *);
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods	java_beans_beancontext_BeanContextSupport__24BCSIterator;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs {
    _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs	java_beans_beancontext_BeanContextSupport__24BCSIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs	java_beans_beancontext_BeanContextSupport__24BCSIterator;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object {
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextSupport__24BCSIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextSupport__24BCSIterator_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextSupport__24BCSIterator.h <==
// public final class java.beans.beancontext.BeanContextSupport$BCSIterator

// class file dependencies
// @dep_class ade893ef1e681103 java_beans_beancontext_BeanContextSupport__24BCSIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextSupport__24BCSIterator_H_
#define _JC_java_beans_beancontext_BeanContextSupport__24BCSIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object;

typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vmethods	java_beans_beancontext_BeanContextSupport__24BCSIterator;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs {
    _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_refs	java_beans_beancontext_BeanContextSupport__24BCSIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$sub_nonrefs	java_beans_beancontext_BeanContextSupport__24BCSIterator;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$object {
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$vtype _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextSupport__24BCSIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextSupport__24BCSIterator$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextSupport__24BCSIterator_H_ */
